package com.ibiz.core.r7rt_wf.service.impl;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.HashMap;
import java.math.BigInteger;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.stereotype.Service;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import com.ibiz.core.client.model.IWFIAAction;
import com.ibiz.core.r7rt_wf.domain.WFIAAction;
import com.ibiz.core.r7rt_wf.filter.WFIAActionSearchContext;
import com.ibiz.core.r7rt_wf.service.IWFIAActionService;
import org.springframework.beans.factory.annotation.Autowired;
import com.ibiz.util.SearchResult;

/**
 * 实体[工作流步骤操作] 服务对象接口实现
 */
@Service
public class WFIAActionServiceImpl implements IWFIAActionService {

    @Autowired
    private com.ibiz.core.client.service.IWFIAActionClientService wFIAActionClientService;

    @Override
    public boolean remove(String wfiaactionid) {
        boolean bOk = false ;
        IWFIAAction clientModel = wFIAActionClientService.createModel();
        clientModel.setWFIAActionId(wfiaactionid);
        wFIAActionClientService.remove(clientModel) ;
        bOk = true ;
        return bOk ;
    }

    @Override
    public boolean update(WFIAAction wfiaaction) {
        boolean bOk = false ;
        IWFIAAction clientModel = this.convert2Model(wfiaaction,null);
        wFIAActionClientService.update(clientModel) ;
        this.convert2Domain(clientModel,wfiaaction) ;
        bOk = true;
        return bOk ;
    }

    @Override
    public boolean save(WFIAAction wfiaaction) {
        if(wfiaaction.getWFIAActionId()==null){
    		return create(wfiaaction);
    	}else{
            if(this.get(wfiaaction.getWFIAActionId())!=null){
    			return update(wfiaaction);
    		}
    		return create(wfiaaction);
    	}
    }

    @Override
    public WFIAAction get(String wfiaactionid) {
        IWFIAAction clientModel = wFIAActionClientService.createModel();
        clientModel.setWFIAActionId(wfiaactionid);
        wFIAActionClientService.get(clientModel) ;
        return this.convert2Domain(clientModel,null);
    }

    @Override
    public WFIAAction get(WFIAAction wfiaaction) {
        WFIAAction retwfiaaction = this.get(wfiaaction.getWFIAActionId()) ;
    	BeanCopier copier=BeanCopier.create(retwfiaaction.getClass(), wfiaaction.getClass(), false);
        copier.copy(retwfiaaction, wfiaaction, null);
        return wfiaaction ;
    }

    @Override
    public boolean checkKey(WFIAAction wfiaaction) {
        return true;
    }

    @Override
    public WFIAAction getDraft(WFIAAction wfiaaction) {
        return wfiaaction;
    }

    @Override
    public boolean create(WFIAAction wfiaaction) {
        boolean bOk = false ;
        IWFIAAction clientModel = this.convert2Model(wfiaaction,null);
        wFIAActionClientService.create(clientModel) ;
        this.convert2Domain(clientModel,wfiaaction);
        bOk = true ;

        return bOk ;
    }

    /**
     * 查询集合 DEFAULT
     */
    @Override
    public Page<WFIAAction> searchDefault(WFIAActionSearchContext context) {
        List<WFIAAction> list = new ArrayList<WFIAAction>();
        Page<com.ibiz.core.client.model.IWFIAAction> clientModelList = wFIAActionClientService.fetchDefault(context) ;
        for(com.ibiz.core.client.model.IWFIAAction clientModel : clientModelList){
            list.add( this.convert2Domain(clientModel,null));
        }
        return new PageImpl<WFIAAction>(list, context.getPageable(), clientModelList.getTotalElements());
    }




    public IWFIAAction convert2Model(WFIAAction domain , IWFIAAction model) {
        if(domain == null)
            return model ;
        if(model==null){
            model = wFIAActionClientService.createModel() ;
        }

         if(domain.getWFIAActionIdDirtyFlag())
            model.setWFIAActionId(domain.getWFIAActionId());
         if(domain.getUpdateDateDirtyFlag())
            model.setUpdateDate(domain.getUpdateDate());
         if(domain.getUserData2DirtyFlag())
            model.setUserData2(domain.getUserData2());
         if(domain.getOpinionDirtyFlag())
            model.setOpinion(domain.getOpinion());
         if(domain.getActionTypeDirtyFlag())
            model.setActionType(domain.getActionType());
         if(domain.getCreateDateDirtyFlag())
            model.setCreateDate(domain.getCreateDate());
         if(domain.getPersonListDirtyFlag())
            model.setPersonList(domain.getPersonList());
         if(domain.getUserDataDirtyFlag())
            model.setUserData(domain.getUserData());
         if(domain.getCreateManDirtyFlag())
            model.setCreateMan(domain.getCreateMan());
         if(domain.getUpdateManDirtyFlag())
            model.setUpdateMan(domain.getUpdateMan());
         if(domain.getWFStepIdDirtyFlag())
            model.setWFStepId(domain.getWFStepId());
         if(domain.getWFIAActionNameDirtyFlag())
            model.setWFIAActionName(domain.getWFIAActionName());
         if(domain.getOpPersonDirtyFlag())
            model.setOpPerson(domain.getOpPerson());
         if(domain.getWFInstanceIdDirtyFlag())
            model.setWFInstanceId(domain.getWFInstanceId());
        return model ;
    }

    public WFIAAction convert2Domain( IWFIAAction model ,WFIAAction domain) {
        if(model == null)
            return domain ;
        if(domain == null){
            domain = new WFIAAction();
        }

        if(model.getWFIAActionIdDirtyFlag())
            domain.setWFIAActionId(model.getWFIAActionId());
        if(model.getUpdateDateDirtyFlag())
            domain.setUpdateDate(model.getUpdateDate());
        if(model.getUserData2DirtyFlag())
            domain.setUserData2(model.getUserData2());
        if(model.getOpinionDirtyFlag())
            domain.setOpinion(model.getOpinion());
        if(model.getActionTypeDirtyFlag())
            domain.setActionType(model.getActionType());
        if(model.getCreateDateDirtyFlag())
            domain.setCreateDate(model.getCreateDate());
        if(model.getPersonListDirtyFlag())
            domain.setPersonList(model.getPersonList());
        if(model.getUserDataDirtyFlag())
            domain.setUserData(model.getUserData());
        if(model.getCreateManDirtyFlag())
            domain.setCreateMan(model.getCreateMan());
        if(model.getUpdateManDirtyFlag())
            domain.setUpdateMan(model.getUpdateMan());
        if(model.getWFStepIdDirtyFlag())
            domain.setWFStepId(model.getWFStepId());
        if(model.getWFIAActionNameDirtyFlag())
            domain.setWFIAActionName(model.getWFIAActionName());
        if(model.getOpPersonDirtyFlag())
            domain.setOpPerson(model.getOpPerson());
        if(model.getWFInstanceIdDirtyFlag())
            domain.setWFInstanceId(model.getWFInstanceId());
        return domain ;
    }


}
